@@ -405,7 +405,11 @@ static void call_reconnect(wb::WBContextSQLIDE *sqlide)
 {
   SqlEditorForm *db_sql_editor= sqlide->get_active_sql_editor();
   if (db_sql_editor && !db_sql_editor->is_running_query())
+  {
+    db_sql_editor->grt_manager()->replace_status_text("Reconnecting...");
     db_sql_editor->connect();
+    db_sql_editor->grt_manager()->replace_status_text("Connection reopened");
+  }
 }
 
 
