@@ -544,7 +544,7 @@ bool TableColumnsListBE::set_field(const NodeId &node, int column, const std::st
 
     if ((ColumnListColumns)column == Name)
     {
-      col_name= rtrim(value);
+      col_name= base::trim_right(value);
       _owner->add_column(col_name);
 
       db_ColumnRef col(_owner->get_table()->columns()[node[0]]);
@@ -591,7 +591,7 @@ bool TableColumnsListBE::set_field(const NodeId &node, int column, const std::st
   {
   case Name:
     {
-      std::string value_= rtrim(value);
+      std::string value_= base::trim_right(value);
       if (old != value_)
         _owner->rename_column(col, value_);
     }
@@ -630,7 +630,7 @@ bool TableColumnsListBE::set_field(const NodeId &node, int column, const std::st
     {
       AutoUndoEdit undo(_owner, col, "defaultValue");
 
-      std::string value_= rtrim(value);
+      std::string value_= base::trim_right(value);
       bec::ColumnHelper::set_default_value(col, value_.empty() ? "" : quote_value_if_needed(col, value_));
       _owner->update_change_date();
 
@@ -2564,7 +2564,7 @@ void TableEditorBE::set_name(const std::string &name)
 
     AutoUndoEdit undo(this, get_object(), "name");
     bec::ValidationManager::validate_instance(_table, CHECK_NAME);
-    std::string name_= rtrim(name);
+    std::string name_= base::trim_right(name);
     //DBObjectEditorBE::set_name(name_);
     get_dbobject()->name(name_);
     update_change_date();
