@@ -236,27 +236,27 @@ void DbDriverParams::init(
   const db_mgmt_DriverRef &driver,
   const db_mgmt_ConnectionRef &stored_conn,
   const boost::function<void (bool)> &suspend_layout,
-  const boost::function<void ()> &clear_param_controls,
+  const boost::function<void ()> &begin_layout,
   const boost::function<void (DbDriverParam*, ControlType, const ControlBounds&, const std::string &)> &create_control,
+  const boost::function<void ()> &end_layout,
   bool skip_schema,
   int first_row_label_width,
   int hmargin,
   int vmargin)
 {
-  if(suspend_layout)
-    suspend_layout(true);
+  begin_layout();
 
-  if(clear_param_controls)
-    clear_param_controls();
   free_dyn_mem();
 
+  if (suspend_layout)
+    suspend_layout(true);
+
   _driver= driver;
   grt::ListRef<db_mgmt_DriverParameter> params= driver->parameters();
   size_t param_count= params.count();
 
   _collection.resize(param_count);
   _control_name_index.clear();
-
   DbDriverParam *param_handle;
   bool trim_schema = false;
   // create param handles
@@ -268,21 +268,17 @@ void DbDriverParams::init(
       trim_schema = true;
       continue;
     }
-
     param_handle= new DbDriverParam(param, stored_conn);
     _collection[_control_name_index.size()]= param_handle;
     _control_name_index[control_name_prefix + *param->name()]= param_handle;
   }
-  
   if (trim_schema)
     _collection.resize(param_count-1);
-
   for (int layout_type= 0; layout_type < 2; ++layout_type) // separate cycle for controls tagged as advanced layout
   {
     LayoutRows rows;
     LayoutRow row(0, hmargin);
     int y_offset= vmargin;
-
     for (Collection::iterator i= _collection.begin(); i != _collection.end(); ++i)
     {
       param_handle= *i;
@@ -364,9 +360,9 @@ void DbDriverParams::init(
       row_index++;
     }
   }
-
-  if(suspend_layout)
-    suspend_layout(false);
+  suspend_layout(false);
+  
+  end_layout();
 }
 
 
@@ -379,14 +375,18 @@ void DbDriverParams::free_dyn_mem()
 
 grt::DictRef DbDriverParams::get_params() const
 {
-  grt::DictRef params(_driver.get_grt());
-  for (Collection::const_iterator i= _collection.begin(); i != _collection.end(); ++i)
+  if (_driver.is_valid())
   {
-    DbDriverParam *param_handle= *i;
-    if (param_handle->get_value().is_valid())
-      params.set(param_handle->object()->name(), param_handle->get_value());
+    grt::DictRef params(_driver.get_grt());
+    for (Collection::const_iterator i= _collection.begin(); i != _collection.end(); ++i)
+    {
+      DbDriverParam *param_handle= *i;
+      if (param_handle->get_value().is_valid())
+        params.set(param_handle->object()->name(), param_handle->get_value());
+    }
+    return params;
   }
-  return params;
+  return grt::DictRef();
 }
 
 
@@ -434,11 +434,13 @@ void DbConnection::init(const db_mgmt_ManagementRef &mgmt, bool skip_schema)
 
 void DbConnection::set_control_callbacks(
   const boost::function<void (bool)> &suspend_layout,
-  const boost::function<void ()> &clear_param_controls,
-  const boost::function<void (DbDriverParam*, ControlType, const ControlBounds&, const std::string &)> &create_control)
+  const boost::function<void ()> &begin_layout,
+  const boost::function<void (DbDriverParam*, ControlType, const ControlBounds&, const std::string &)> &create_control,
+  const boost::function<void ()> &end_layout)
 {
   _suspend_layout = suspend_layout;
-  _clear_param_controls= clear_param_controls;
+  _begin_layout = begin_layout;
+  _end_layout = end_layout;
   _create_control= create_control;
 }
 
@@ -469,12 +471,14 @@ void DbConnection::set_connection(const db_mgmt_ConnectionRef &connection)
     if (_connection.is_valid() && !_connection->driver().is_valid())
       _connection->driver(get_active_driver());
 
+    /*
     _db_driver_param_handles.init(connection->driver(),
                                   _connection,
                                   _suspend_layout,
                                   _clear_param_controls,
                                   _create_control,
                                   _skip_schema);
+     */
   }
 }
 
@@ -485,30 +489,30 @@ void DbConnection::set_connection_keeping_parameters(const db_mgmt_ConnectionRef
   {
     _connection= connection;
     _connection->driver(get_active_driver());
-    grt::merge_contents(_connection->parameterValues(), _db_driver_param_handles.get_params(), true);
+    grt::DictRef curparams(_db_driver_param_handles.get_params());
+    if (curparams.is_valid())
+      grt::merge_contents(_connection->parameterValues(), curparams, true);
   }
 }
 
 
 void DbConnection::set_active_driver(int driver_index)
 {
-  //! if (driver_index != _active_db_driver_index)
-  {    
-    _active_db_driver_index= driver_index;
-    
-    if (_connection.is_valid())
-      _connection->driver(get_active_driver());
-
-    _db_driver_param_handles.init(get_active_driver(),
-                                  _connection,
-                                  _suspend_layout,
-                                  _clear_param_controls,
-                                  _create_control,
-                                  _skip_schema);
-    
-    if (_connection.is_valid())
-      save_changes();
-  }
+  _active_db_driver_index= driver_index;
+  
+  if (_connection.is_valid())
+    _connection->driver(get_active_driver());
+  
+  _db_driver_param_handles.init(get_active_driver(),
+                                _connection,
+                                _suspend_layout,
+                                _begin_layout,
+                                _create_control,
+                                _end_layout,
+                                _skip_schema);
+  
+  if (_connection.is_valid())
+    save_changes();
 }
 
 
