@@ -276,6 +276,8 @@ void SqlEditorFE::add_search_history(const std::string &entry)
 void SqlEditorFE::do_find(bool forward)
 {
   std::string text = _find_entry->get_text();
+  if (text.empty())
+    return;
   add_search_history(text);
   switch (find_text(text, false, false, forward))
   {
@@ -297,11 +299,12 @@ void SqlEditorFE::do_find(bool forward)
 
 void SqlEditorFE::do_replace(ReplaceType type)
 {
+  std::string search_text = _find_entry->get_text();
   switch (type)
   {
     case ReplaceAll:
+      if (!search_text.empty())
       {
-        std::string search_text = _find_entry->get_text();
         std::string replace_text = _replace_entry->get_text();
         //int searchFlags= 0;
         //  searchFlags |= SCFIND_MATCHCASE;
@@ -333,7 +336,7 @@ void SqlEditorFE::do_replace(ReplaceType type)
       replace_selected_text(_replace_entry->get_text());
       break;
     case FindReplace:
-      if (find_text(_find_entry->get_text(), false, false, true) != NoMatches)
+      if (!search_text.empty() && find_text(search_text, false, false, true) != NoMatches)
         replace_selected_text(_replace_entry->get_text());
       break;
   }
