@@ -513,6 +513,17 @@ bool ViewImpl::is_shown(::mforms::View *self)
 
 //-------------------------------------------------------------------------------------------------
 
+void ViewImpl::initialize()
+{
+  Control^ control= get_control<Control>();
+
+  // Can be null, e.g. for non-control objects like dialogs.
+  if (control != nullptr)
+    control->Resize += gcnew EventHandler(this, &ViewImpl::OnResize);
+}
+
+//-------------------------------------------------------------------------------------------------
+
 void ViewImpl::set_size(int width, int height)
 {
   Control^ control= get_control<Control>();
@@ -691,3 +702,17 @@ void ViewImpl::flush_events(::mforms::View *)
 }
 
 //-------------------------------------------------------------------------------------------------
+
+void ViewImpl::OnResize(System::Object ^sender, EventArgs ^e)
+{
+  Control^ control = (Control^)sender;
+
+  if (control->Tag != nullptr)
+  {
+    mforms::View* view = ViewImpl::get_backend_control<mforms::View>(control);
+    if (!view->is_destroying())
+      (*view->signal_resized())();
+  }
+}
+
+//-------------------------------------------------------------------------------------------------
