@@ -1,5 +1,5 @@
 /* 
-* Copyright (c) 2009, 2010, 2011 Oracle and/or its affiliates. All rights reserved.
+* Copyright (c) 2009, 2010, 2011, 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
@@ -510,6 +510,9 @@ public:
         right_catalog = _right_db.db_catalog();
       else if (_source_page->get_right_source() == DataSourceSelector::FileSource)
         right_catalog = _import_destination_file->get_catalog();
+      else if (_source_page->get_right_source() == DataSourceSelector::ModelSource)
+        right_catalog = _be.get_model_catalog();
+
 
       _diffs_page->set_src(right_catalog);
       _diffs_page->set_dst(left_catalog);
