@@ -433,16 +433,8 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
                     else:
                         # continue without a db connection
                        self.sql_enabled = False 
-                elif self.server_control:
-                    if mforms.Utilities.show_warning("Could not connect to MySQL Server at %s" % err.location,
-                            "%s\nYou may continue anyway, but some functionality will be unavailable." % err,
-                            "Continue", "Cancel", "") != mforms.ResultOk:
-                        raise OperationCancelledError("Could not connect to MySQL")
-                    else:
-                        self.sql_enabled = False
-                else:  # We have neither sql connection nor management method
-                    raise Exception('Could not connect to MySQL Server and no management method is available')
-
+                else:
+                    self.sql_enabled = False
 
     def shutdown(self):
         self.events.event('shutdown')
