@@ -1,4 +1,4 @@
-# Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -39,7 +39,7 @@ SCHEMA_DDL_RIGHTS = [
 "Alter_priv",
 "References_priv",
 "Index_priv",
-"Create_view_priv", 
+"Create_view_priv",
 "Create_routine_priv",
 "Alter_routine_priv",
 "Drop_priv",
@@ -54,7 +54,7 @@ SCHEMA_OTHER_RIGHTS = [
 
 
 AUTHENTICATION_PLUGIN_TYPES = {
-None : {"name" : "Standard", 
+None : {"name" : "Standard",
         "auth_string_label": "",
         "enable_host": True,
         "enable_password" : True,
@@ -85,8 +85,8 @@ def dLabel(text):
     l = newLabel(text)
     l.set_style(mforms.SmallHelpTextStyle)
     return l
-    
-    
+
+
 class AddSchemaPrivilegeForm(mforms.Form):
     def __init__(self, secman, user=""):
         mforms.Form.__init__(self, None, mforms.FormResizable | mforms.FormMinimizable)
@@ -99,11 +99,11 @@ class AddSchemaPrivilegeForm(mforms.Form):
         box.set_padding(12)
         box.set_spacing(8)
         self.set_content(box)
-        
+
         label = newLabel()
         label.set_text("Select the Host and the Schema for which the user '%s'\nwill have the privileges you want to define."%user)
         box.add(label, False, True)
-        
+
         panel = newPanel(mforms.TitledBoxPanel)
         panel.set_title("Host")
         box.add(panel, False, True)
@@ -113,32 +113,32 @@ class AddSchemaPrivilegeForm(mforms.Form):
         table.set_row_count(3)
         table.set_column_count(3)
         table.set_row_spacing(8)
-        
+
         self.host1 = newRadioButton(mforms.RadioButton.new_id())
         self.host1.set_active(True)
         self.host1.add_clicked_callback(self.host_radio_changed)
         self.host1.set_text("Any Host (%)")
         table.add(self.host1, 0, 1, 0, 1, mforms.HFillFlag)
-        
+
         self.host2 = newRadioButton(self.host1.group_id())
         self.host2.set_text("Hosts matching pattern or name:")
         self.host2.add_clicked_callback(self.host_radio_changed)
         table.add(self.host2, 0, 1, 1, 2, mforms.HFillFlag)
-        
+
         self.host2entry = newTextEntry()
         table.add(self.host2entry, 1, 2, 1, 2, mforms.HFillFlag|mforms.HExpandFlag)
-                
+
         self.host3 = newRadioButton(self.host1.group_id())
         self.host3.set_text("Selected host:")
         self.host3.add_clicked_callback(self.host_radio_changed)
         table.add(self.host3, 0, 1, 2, 3, mforms.HFillFlag)
-        
+
         self.host3sel = newSelector()
         table.add(self.host3sel, 1, 2, 2, 3, mforms.HFillFlag|mforms.HExpandFlag)
-        
+
         hosts = [h for u,h in secman.account_names if u == user]
         self.host3sel.add_items(hosts)
-        
+
 
         panel = newPanel(mforms.TitledBoxPanel)
         panel.set_title("Schema")
@@ -149,26 +149,26 @@ class AddSchemaPrivilegeForm(mforms.Form):
         table.set_row_count(3)
         table.set_column_count(3)
         table.set_row_spacing(8)
-        
+
         self.schema1 = newRadioButton(mforms.RadioButton.new_id())
         self.schema1.set_active(True)
         self.schema1.add_clicked_callback(self.schema_radio_changed)
         self.schema1.set_text("Any Schema (%)")
         table.add(self.schema1, 0, 1, 0, 1, mforms.HFillFlag)
-        
+
         self.schema2 = newRadioButton(self.schema1.group_id())
         self.schema2.add_clicked_callback(self.schema_radio_changed)
         self.schema2.set_text("Schemas matching pattern or name:")
         table.add(self.schema2, 0, 1, 1, 2, mforms.HFillFlag)
-        
+
         self.schema2entry = newTextEntry()
         table.add(self.schema2entry, 1, 2, 1, 2, mforms.HFillFlag|mforms.HExpandFlag)
-                
+
         self.schema3 = newRadioButton(self.schema1.group_id())
         self.schema3.add_clicked_callback(self.schema_radio_changed)
         self.schema3.set_text("Selected schema:")
         table.add(self.schema3, 0, 1, 2, 3, mforms.HFillFlag)
-        
+
         self.schema3sel = newListBox(False)
         table.add(self.schema3sel, 1, 2, 2, 3, mforms.HFillFlag|mforms.HExpandFlag|mforms.VFillFlag|mforms.VExpandFlag)
         self.schema3sel.add_items(self.secman.schema_names)
@@ -185,12 +185,12 @@ class AddSchemaPrivilegeForm(mforms.Form):
         self.cancel = newButton()
         self.cancel.set_text("Cancel")
         bbox.add_end(self.cancel, False, True)
-        
+
         self.set_size(450, 500)
-    
+
         self.host_radio_changed()
         self.schema_radio_changed()
-    
+
         self.center()
 
 
@@ -203,7 +203,7 @@ class AddSchemaPrivilegeForm(mforms.Form):
         self.schema2entry.set_enabled(self.schema2.get_active())
         self.schema3sel.set_enabled(self.schema3.get_active())
 
-    
+
     def run(self):
         if self.run_modal(self.ok, self.cancel):
             if self.host1.get_active():
@@ -274,22 +274,22 @@ class SecurityAccount(mforms.Box):
 
         self.revert_button = newButton()
         self.revert_button.set_text("Revert")
-        bottom_box.add_end(self.revert_button, False, True)        
+        bottom_box.add_end(self.revert_button, False, True)
         self.revert_button.add_clicked_callback(self.revert)
 
         self.revoke_all_button = newButton()
         self.revoke_all_button.set_text("Revoke All Privileges")
-        bottom_box.add_end(self.revoke_all_button, False, True)        
+        bottom_box.add_end(self.revoke_all_button, False, True)
         self.revoke_all_button.add_clicked_callback(self.revoke_all)
         self.revoke_all_button.set_tooltip("Immediately remove all privileges from the account, from every object at all levels.\nThe account itself will be left untouched and logins will still be possible.")
-            
+
         self.add(bottom_box, False, True)
 
         account_list_box = newBox(False)
         account_list_box.set_spacing(8)
         account_list_box.set_size(220, -1)
         top_box.add(account_list_box, False, True)
-    
+
         label = newLabel("User Accounts")
         account_list_box.add(label, False, True)
 
@@ -308,16 +308,16 @@ class SecurityAccount(mforms.Box):
         self.content_box = abox = newBox(False)
         abox.set_spacing(8)
         top_box.add(abox, True, True)
-    
+
         self.account_label = newLabel("Select an account to edit or click Add Account to create a new one")
         self.account_label.set_style(mforms.BoldStyle)
-        
+
         abox.add(self.account_label, False, True)
 
- 
+
         tabView = newTabView(False)
         abox.add(tabView, True, True)
-        
+
         ##
         vbox = newBox(False)
         vbox.set_spacing(12)
@@ -326,26 +326,26 @@ class SecurityAccount(mforms.Box):
 
         table = newTable()
         vbox.add(table, False, True)
-                        
+
         table.set_row_count(7)
         table.set_column_count(3)
         table.set_row_spacing(8)
         table.set_column_spacing(8)
-        
+
         self.username = newTextEntry()
         self.username.set_size(150, -1)
         self.username.add_changed_callback(self.set_dirty)
-        self.username.set_max_length(16) # max username length for mysql 
+        self.username.set_max_length(16) # max username length for mysql
         self.password = newTextEntry(mforms.PasswordEntry)
         self.password.set_size(150, -1)
         self.password.add_changed_callback(self.set_dirty)
         self.confirm = newTextEntry(mforms.PasswordEntry)
         self.confirm.set_size(150, -1)
         self.confirm.add_changed_callback(self.set_dirty)
-        
+
         self.hostlimithost = newTextEntry()
         self.hostlimithost.add_changed_callback(self.hostlimithost_changed)
-        
+
         table.add(rLabel("Login Name:"), 0, 1, 0, 1, mforms.HFillFlag)
         table.add(self.username, 1, 2, 0, 1, mforms.HFillFlag)
         table.add(dLabel("You may create multiple accounts with the same name\nto connect from different hosts."), 2, 3, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
@@ -384,7 +384,7 @@ class SecurityAccount(mforms.Box):
         self.hostlimit_box.add(self.hostlimithost_valid_icon, False, False)
         self.hostlimit_box.add(add(dLabel("% and _ wildcards may be used")), True, True)
         table.add(self.hostlimit_box, 2, 3, 2, 3, mforms.HFillFlag|mforms.HExpandFlag)
-        
+
         table.add(add(rLabel("Password:")), 0, 1, 3, 4, mforms.HFillFlag)
         table.add(self.password, 1, 2, 3, 4, mforms.HFillFlag)
         table.add(add(dLabel("Type a password to reset it.")), 2, 3, 3, 4, mforms.HFillFlag|mforms.HExpandFlag)
@@ -405,10 +405,10 @@ class SecurityAccount(mforms.Box):
             vbox.add(self.auth_string_help, False, True)
 
         ####
-        
+
         box = newBox(False)
         tabView.add_page(box, "Administrative Roles")
-        
+
         lbox = newBox(True)
         box.add(lbox, True, True)
         lbox.set_spacing(12)
@@ -445,14 +445,14 @@ class SecurityAccount(mforms.Box):
         table.set_row_spacing(8)
         table.set_row_count(4)
         table.set_column_count(3)
-                
+
         table.add(rLabel("Max. Queries:"), 0, 1, 0, 1, 0)
         self.max_questions = newTextEntry()
         self.max_questions.set_size(60, -1)
         self.max_questions.add_changed_callback(self.set_dirty)
         table.add(self.max_questions, 1, 2, 0, 1, mforms.HFillFlag)
         table.add(dLabel("Number of queries the account can execute within one hour."), 2, 3, 0, 1, mforms.HFillFlag|mforms.HExpandFlag)
-        
+
         table.add(rLabel("Max. Updates:"), 0, 1, 1, 2, 0)
         self.max_updates = newTextEntry()
         self.max_updates.set_size(60, -1)
@@ -466,7 +466,7 @@ class SecurityAccount(mforms.Box):
         self.max_connections.add_changed_callback(self.set_dirty)
         table.add(self.max_connections, 1, 2, 2, 3, mforms.HFillFlag)
         table.add(dLabel("The number of times the account can connect to the server per hour."), 2, 3, 2, 3, mforms.HFillFlag|mforms.HExpandFlag)
-        
+
         table.add(rLabel("Concurrent Connections:"), 0, 1, 3, 4, 0)
         self.max_uconnections = newTextEntry()
         self.max_uconnections.set_size(60, -1)
@@ -477,7 +477,7 @@ class SecurityAccount(mforms.Box):
         self.resume_layout()
 
         self.user_selected()
-        
+
     @property
     def active_plugins(self):
         return [name for name, ptype in self.owner.ctrl_be.server_active_plugins if ptype == "AUTHENTICATION"]
@@ -556,16 +556,16 @@ class SecurityAccount(mforms.Box):
             roles = self._selected_user.admin_roles
             for i in range(self.role_list.count()):
                 self.role_list.set_bool(i, 0, self.role_list.get_string(i, 1) in roles)
-            
+
             self.set_dirty()
-            
+
             self.refresh_priv_list()
-        
-                
+
+
     def host_limit_clicked(self):
         self.hostlimithost.set_enabled(self.hostlimit.get_active())
         self.set_dirty()
-        
+
 
     def user_selected(self):
         sel = self.user_list.get_selected()
@@ -576,14 +576,14 @@ class SecurityAccount(mforms.Box):
 
         self.dup_button.set_enabled(False)
         self.del_button.set_enabled(False)
-        
+
         self.refresh_priv_list()
 
         if sel >= 0:
             user, host = eval(self.user_list.get_row_tag(sel))
             self.account_label.set_text("Details for account %s@%s" % (user, host))
 
-            user_info = self.owner.secman.async_get_account(self.show_user, user, host)
+            self.owner.secman.async_get_account(self.show_user, user, host)
         else:
             self.account_label.set_text("Select an account to edit or click Add Account to create a new one")
 
@@ -611,13 +611,13 @@ class SecurityAccount(mforms.Box):
             self.confirm.set_value("")
 
             self.set_hostlimithost(user.host)
-            
+
             if self.auth_type_list:
                 try:
                     index = self.auth_type_list.index(user.auth_plugin or None)
-                except ValueError, x:
-                    mforms.Utilities.show_warning("Invalid Authentication Plugin", 
-                              "User %s has plugin type %s, which is not listed as a known authentication plugin by the server." % (user.formatted_name(), user.auth_plugin), 
+                except ValueError:
+                    mforms.Utilities.show_warning("Invalid Authentication Plugin",
+                              "User %s has plugin type %s, which is not listed as a known authentication plugin by the server." % (user.formatted_name(), user.auth_plugin),
                               "OK", "", "")
                     return
 
@@ -631,17 +631,17 @@ class SecurityAccount(mforms.Box):
             self.max_updates.set_value(str(user.max_updates))
             self.max_connections.set_value(str(user.max_connections))
             self.max_uconnections.set_value(str(user.max_user_connections))
-            
+
             roles = user.admin_roles
             for i in range(self.role_list.count()):
                 self.role_list.set_bool(i, 0, self.role_list.get_string(i, 1) in roles)
-            
+
             self.refresh_priv_list()
         else:
             self.username.set_value("")
             self.password.set_value("")
             self.confirm.set_value("")
-            
+
             self.set_hostlimithost("")
 
             if self.auth_string_param:
@@ -651,18 +651,18 @@ class SecurityAccount(mforms.Box):
             self.max_updates.set_value("")
             self.max_connections.set_value("")
             self.max_uconnections.set_value("")
-            
+
             for i in range(self.role_list.count()):
                 self.role_list.set_bool(i, 0, False)
-    
-    
+
+
     def _find_user_position(self, user, host):
         users_count = len(self.owner.secman.account_names)
         for row in range(users_count):
             if (user, host) == ( self.user_list.get_string(row, 0), self.user_list.get_string(row, 1) ):
                 return row
         return users_count - 1  # Control shouldn't get here
-    
+
     def add_account(self):
         account = self.owner.secman.create_account()
         self.refresh()
@@ -695,7 +695,7 @@ class SecurityAccount(mforms.Box):
 
     def refresh(self):
         selected_row = None
-        
+
         su = self._selected_user
         suo = self._selected_user_original
         self.user_list.freeze_refresh()
@@ -709,7 +709,7 @@ class SecurityAccount(mforms.Box):
             self.user_list.set_row_tag(row, repr((user, host)))
             if self._selected_user and (user == self._selected_user.username and host == self._selected_user.host):
                 selected_row = row
-        
+
         if selected_row is not None:
             self.user_list.set_selected(selected_row)
             self.user_selected()
@@ -754,11 +754,11 @@ class SecurityAccount(mforms.Box):
         self.save_button.set_enabled(False)
         self.revert_button.set_enabled(False)
         self.user_list.set_enabled(True)
-  
-  
+
+
     def revoke_all(self):
         if self._selected_user:
-            if Utilities.show_message("Revoke All Privileges", 
+            if Utilities.show_message("Revoke All Privileges",
                   "Please confirm revokation of all privileges for the account '%s'@'%s'.\nNote: the account itself will be maintained."%(self._selected_user.username, self._selected_user.host),
                   "Revoke", "Cancel", "") == mforms.ResultOk:
                 self._selected_user.revoke_all()
@@ -772,15 +772,15 @@ class SecurityAccount(mforms.Box):
         if not self._selected_user.is_commited:
             self.owner.secman.delete_account(self._selected_user)
         self.refresh()
-    
-    
+
+
     def commit(self):
         if self._selected_user:
             username = self.username.get_string_value()
             host = self.hostlimithost.get_string_value()
-            
+
             is_new_user = not self._selected_user.is_commited
-            
+
             password_unneeded = False
             if self.has_extra_plugins and not AUTHENTICATION_PLUGIN_TYPES[self.selected_plugin_type()]["enable_password"]:
                 password_unneeded = True
@@ -798,10 +798,40 @@ class SecurityAccount(mforms.Box):
            # else:
            #     self._selected_user.host = "%"
 
-            self._selected_user.max_questions = int(self.max_questions.get_string_value())
-            self._selected_user.max_updates = int(self.max_updates.get_string_value())
-            self._selected_user.max_connections = int(self.max_connections.get_string_value())
-            self._selected_user.max_user_connections = int(self.max_uconnections.get_string_value())
+            try:
+                self._selected_user.max_questions = int(self.max_questions.get_string_value())
+                if self._selected_user.max_questions < 0: raise ValueError
+            except ValueError:
+                Utilities.show_error('Wrong Value for Max. Queries',
+                        'Cannot convert "%s" to a valid non-negative integer.\nPlease correct this value and try again.' % self.max_questions.get_string_value(),
+                        'OK', '', '')
+                return
+
+            try:
+                self._selected_user.max_updates = int(self.max_updates.get_string_value())
+                if self._selected_user.max_updates < 0: raise ValueError
+            except ValueError:
+                Utilities.show_error('Wrong Value for Max. Updates',
+                        'Cannot convert "%s" to a valid non-negative integer.\nPlease correct this value and try again.' % self.max_updates.get_string_value(),
+                        'OK', '', '')
+                return
+
+            try:
+                self._selected_user.max_connections = int(self.max_connections.get_string_value())
+                if self._selected_user.max_connections < 0: raise ValueError
+            except ValueError:
+                Utilities.show_error('Wrong Value for Max. Connections',
+                        'Cannot convert "%s" to a valid non-negative integer.\nPlease correct this value and try again.' % self.max_connections.get_string_value(),
+                        'OK', '', '')
+                return
+            try:
+                self._selected_user.max_user_connections = int(self.max_uconnections.get_string_value())
+                if self._selected_user.max_user_connections < 0: raise ValueError
+            except ValueError:
+                Utilities.show_error('Wrong Value for Concurrent Connections',
+                        'Cannot convert "%s" to a valid non-negative integer.\nPlease correct this value and try again.' % self.max_uconnections.get_string_value(),
+                        'OK', '', '')
+                return
 
             if is_new_user and self.has_extra_plugins:
                 self._selected_user.auth_plugin = self.selected_plugin_type()
@@ -816,15 +846,19 @@ class SecurityAccount(mforms.Box):
                       str(exc), "OK", "", "")
                 return
             except PermissionDeniedError, exc:
-                Utilities.show_error("Save Account Changes",
+                Utilities.show_error("Permission Errors",
                       str(exc), "OK", "", "")
                 return
-            
+            except Exception, exc:
+                Utilities.show_error("Error Saving Account",
+                      str(exc), "OK", "", "")
+                return
+
             the_name = self._selected_user.formatted_name()
-            
+
             self._selected_user.load(self._selected_user.username, self._selected_user.host)
             self.owner.refresh()
-            
+
             if is_new_user:
                 mforms.App.get().set_status_text("Created account '%s'" % the_name)
             else:
@@ -838,19 +872,19 @@ class SecuritySchemaPrivileges(mforms.Box):
         mforms.Box.__init__(self, True)
         self.set_managed()
         self.owner = owner
-        
+
         self._selected_user = None
         self._selected_user_original = None
-      
+
         self.suspend_layout()
         self.set_spacing(8)
         self.set_padding(8)
-        
+
         schema_list_box = newBox(False)
         schema_list_box.set_spacing(8)
         schema_list_box.set_size(150, -1)
         self.add(schema_list_box, False, True)
-    
+
         #searchbox = TextEntry(SearchEntry)
         #schema_list_box.add(searchbox, False, True)
 
@@ -866,9 +900,9 @@ class SecuritySchemaPrivileges(mforms.Box):
         self.content_box = priv_vbox = newBox(False)
         priv_vbox.set_spacing(8)
         self.add(priv_vbox, True, True)
-        
+
         priv_vbox.add(newLabel("Select a user and pick the privileges it has for a given Schema and Host combination."), False, True)
-        
+
         self.privs_list = newTreeView(mforms.TreeDefault)
         self.privs_list.add_column(mforms.StringColumnType, "Host", 100, True)
         self.privs_list.add_column(mforms.StringColumnType, "Schema", 100, True)
@@ -877,7 +911,7 @@ class SecuritySchemaPrivileges(mforms.Box):
         self.privs_list.add_changed_callback(self.schema_priv_selected)
 
         priv_vbox.add(self.privs_list, True, True)
-        
+
         bbox = newBox(True)
         bbox.set_spacing(8)
 
@@ -885,14 +919,14 @@ class SecuritySchemaPrivileges(mforms.Box):
 
         self.add_entry_button = newButton()
         self.add_entry_button.set_text("Add Entry...")
-        bbox.add_end(self.add_entry_button, False, True)        
+        bbox.add_end(self.add_entry_button, False, True)
         self.add_entry_button.add_clicked_callback(self.add_entry)
-        
+
         self.del_entry_button = newButton()
         self.del_entry_button.set_text("Delete Entry")
         bbox.add_end(self.del_entry_button, False, True)
         self.del_entry_button.add_clicked_callback(self.del_entry)
-    
+
         priv_vbox.add(bbox, False, True)
 
         self.schema_priv_label = newLabel("")
@@ -915,7 +949,7 @@ class SecuritySchemaPrivileges(mforms.Box):
             cb.add_clicked_callback(self.schema_priv_checked)
             box.add(cb, False, False)
             self.schema_rights_checks[name] = cb
-        panel.add(box)        
+        panel.add(box)
         hbox.add(panel, True, True)
 
         self.schema_ddl_privs_panel = panel = newPanel(mforms.TitledBoxPanel)
@@ -979,14 +1013,14 @@ class SecuritySchemaPrivileges(mforms.Box):
 
         self.save_button = newButton()
         self.save_button.set_text("Save Changes")
-        bottom_box.add_end(self.save_button, False, True)        
+        bottom_box.add_end(self.save_button, False, True)
         self.save_button.add_clicked_callback(self.commit)
-                
+
         self.revert_button = newButton()
         self.revert_button.set_text("Revert")
         bottom_box.add_end(self.revert_button, False, True)
         self.revert_button.add_clicked_callback(self.revert)
-    
+
         priv_vbox.add(bottom_box, False, True)
 
         self.resume_layout()
@@ -1014,7 +1048,7 @@ class SecuritySchemaPrivileges(mforms.Box):
         sel = self.privs_list.get_selected()
         if sel >= 0:
             self._selected_user.entries[sel].privileges = set(privs)
-            
+
             plist = [PrivilegeInfo.get(p, " ")[0] for p in privs]
             plist.sort()
             self.privs_list.set_string(sel, 2, ", ".join(plist) or "none")
@@ -1037,7 +1071,7 @@ class SecuritySchemaPrivileges(mforms.Box):
             self.schema_priv_selected()
 
             self.set_dirty()
-  
+
 
     def del_entry(self):
         sel = self.privs_list.get_selected()
@@ -1059,7 +1093,7 @@ class SecuritySchemaPrivileges(mforms.Box):
 
         self.add_entry_button.set_enabled(False)
         self.add_entry_button.set_enabled(False)
-        
+
         self.show_privileges(None)
 
         if sel >= 0:
@@ -1107,16 +1141,16 @@ class SecuritySchemaPrivileges(mforms.Box):
         self.content_box.set_enabled(user != None)
 
         self.unset_dirty()
-    
+
         self.refresh_entry_list(user)
 
         if user is not None:
             self.add_entry_button.set_enabled(True)
-            self.del_entry_button.set_enabled(False)            
+            self.del_entry_button.set_enabled(False)
 
         self.show_privileges(None)
-    
-    
+
+
     def refresh_entry_list(self, user):
         self.privs_list.clear_rows()
         for entry in user and user.entries or []:
@@ -1127,8 +1161,8 @@ class SecuritySchemaPrivileges(mforms.Box):
             plist.sort()
             self.privs_list.set_string(row, 2, ", ".join(plist) or "none")
 
-    
-    
+
+
     def show_privileges(self, entry):
         self.schema_object_privs_panel.set_enabled(entry != None)
         self.schema_ddl_privs_panel.set_enabled(entry != None)
@@ -1153,7 +1187,7 @@ class SecuritySchemaPrivileges(mforms.Box):
             else:
                 text += "will have the following access rights to the schema '%s':" % db
             self.schema_priv_label.set_text(text)
-        
+
             self.del_entry_button.set_enabled(True)
 
             self.grant_all.set_enabled(True)
@@ -1188,7 +1222,7 @@ class SecuritySchemaPrivileges(mforms.Box):
 
 
     def commit(self):
-        if self._selected_user:       
+        if self._selected_user:
             try:
                 self._selected_user.save()
             except PermissionDeniedError, exc:
@@ -1222,13 +1256,13 @@ class WbAdminSecurity(mforms.Box):
 
         self.tabview = newTabView(False)
         self.add(self.tabview, True, True)
-    
+
         self.account_tab = SecurityAccount(self)
         self.tabview.add_page(self.account_tab, "Server Access Management")
 
         self.schema_privs_tab = SecuritySchemaPrivileges(self)
         self.tabview.add_page(self.schema_privs_tab, "Schema Privileges")
-        
+
         self.resume_layout()
 
 
@@ -1253,7 +1287,7 @@ class WbAdminSecurity(mforms.Box):
             self.ui_created = True
         self.update_ui()
         self.refresh()
-        
+
         # Ask the user to remove anonymous accounts if present
         if self.ctrl_be.is_sql_connected():
             try:
@@ -1264,17 +1298,17 @@ class WbAdminSecurity(mforms.Box):
                     privs = self.secman.get_valid_privileges()
             except:
                 privs = []
-                
+
                 if 'DELETE' in privs or 'CREATE USER' in privs:
-                    if Utilities.show_message_and_remember('Anonymous accounts detected', 
+                    if Utilities.show_message_and_remember('Anonymous accounts detected',
                         'Anonymous accounts were detected in the server %s.\nAnonymous accounts can cause great confusion and are also a potential security issue and are advised to be removed. Would you like Workbench to delete them now?.' % logged_servername,
-                        'Delete', 'Leave Accounts', '', 
+                        'Delete', 'Leave Accounts', '',
                         'wb.admin.delete_anonymous_accounts:' + logged_username + '@' + logged_servername,
                         "Don't show this message again") == mforms.ResultOk:
                         for name, host in anon_accounts:
                             self.secman.async_get_account(self.secman.delete_account, name, host)
                 else:
-                    Utilities.show_message_and_remember('Anonymous accounts detected', 
+                    Utilities.show_message_and_remember('Anonymous accounts detected',
                         'Anonymous accounts were detected in the server %s.\nAnonymous accounts can cause great confusion and are also a potential security issue and are advised to be removed. Please ask a DBA to delete them.' % logged_servername,
                         'OK', '', '',
                         'wb.admin.delete_anonymous_accounts:' + logged_username + '|no_privileges|' + '@' + logged_servername,
@@ -1282,7 +1316,7 @@ class WbAdminSecurity(mforms.Box):
                 self.already_asked_for_anon_accounts = True
 
 
-      
+
     def refresh(self):
         if self.ctrl_be.is_sql_connected():
             try:
